Exception: Pvectl::Config::ConfigError

Inherits:
StandardError
  • Object
show all
Defined in:
lib/pvectl/config/errors.rb

Overview

Base error class for all configuration-related exceptions.

All configuration errors inherit from this class, allowing consumers to catch all config errors with a single rescue clause.

Examples:

Catching all configuration errors

begin
  service.load(config: path)
rescue Pvectl::Config::ConfigError => e
  $stderr.puts "Configuration error: #{e.message}"
  exit Pvectl::ExitCodes::CONFIG_ERROR
end