Exception: Pvectl::Error
- Inherits:
-
StandardError
- Object
- StandardError
- Pvectl::Error
- Defined in:
- lib/pvectl.rb
Overview
Base error class for all pvectl-specific exceptions.
All custom errors in the application should inherit from this class, which allows for easy catching of all pvectl errors.